# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-05-27 13:04
# @Author : 毛鹏
from PySide6.QtWidgets import QMessageBox

from mangoui.settings.settings import THEME


def show_failed_message(text: str, title: str = '失败'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Critical)  # type: ignore
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.setStyleSheet(f"""
        QMessageBox {{
            background-color: {THEME.bg_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton {{
            background-color: {THEME.primary_100};
            color: white;
            border-radius: {THEME.border_radius};
            padding: 5px 15px;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200};
        }}
    """)
    msg.exec()


def show_success_message(text: str, title: str = '成功'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Information)  # type: ignore
    msg.setWindowTitle(title)
    msg.setText(text)
    msg.setStyleSheet(f"""
        QMessageBox {{
            background-color: {THEME.bg_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton {{
            background-color: {THEME.primary_100};
            color: white;
            border-radius: {THEME.border_radius};
            padding: 5px 15px;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200};
        }}
    """)
    msg.exec()


def show_warning_message(text: str, title: str = '警告'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Warning)  # type: ignore
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.setStyleSheet(f"""
        QMessageBox {{
            background-color: {THEME.bg_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton {{
            background-color: {THEME.primary_100};
            color: white;
            border-radius: {THEME.border_radius};
            padding: 5px 15px;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200};
        }}
    """)
    msg.exec()


def show_info_message(text: str, title: str = '提示'):
    msg = QMessageBox()
    msg.setIcon(QMessageBox.Information)  # type: ignore
    msg.setText(text)
    msg.setWindowTitle(title)
    msg.setStyleSheet(f"""
        QMessageBox {{
            background-color: {THEME.bg_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton {{
            background-color: {THEME.primary_100};
            color: white;
            border-radius: {THEME.border_radius};
            padding: 5px 15px;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        QPushButton:hover {{
            background-color: {THEME.primary_200};
        }}
    """)
    msg.exec()


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from .layout import LayoutPage
from .layout1 import Layout1Page
from .layout2 import Layout2Page


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import json
from functools import partial
from typing import Optional

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

from mangoui.models.models import *
from mangoui.settings.settings import THEME
from mangoui.widgets.display.mango_label import MangoLabelWidget
from mangoui.widgets.input.mango_toggle import MangoToggle


class MangoTable(QTableWidget):
    click = Signal(object)
    toggle_click = Signal(object)

    def __init__(self, row_column: list[TableColumnModel], row_ope: list[TableMenuItemModel] = None, **kwargs):
        super().__init__()
        self.row_column = row_column
        self.row_ope = row_ope
        self.kwargs = kwargs
        self.column_count = len(row_column)
        self.header_labels = [i.name for i in row_column]
        self.set_stylesheet()
        self.setColumnCount(self.column_count)
        self.setHorizontalHeaderLabels(self.header_labels)
        self.data: Optional[list[dict] | None] = None
        self.set_column_widths()
        self.setSelectionMode(QAbstractItemView.ExtendedSelection)  # type: ignore
        self.setSelectionBehavior(QAbstractItemView.SelectRows)  # type: ignore
        self.verticalHeader().setVisible(False)

        self.setEditTriggers(QTableWidget.NoEditTriggers)  # type: ignore
        self.setMouseTracking(True)

    def set_column_widths(self):
        for index, column in enumerate(self.row_column):
            if column.width:
                self.setColumnWidth(index, column.width)
                self.horizontalHeader().setSectionResizeMode(index, QHeaderView.Fixed)  # type: ignore
            else:
                self.horizontalHeader().setSectionResizeMode(index, QHeaderView.Stretch)  # type: ignore

    def set_value(self, data):
        self.data = data
        self.setRowCount(0)
        if data is None:
            return
        for row_index, row_data in enumerate(data):
            self.insertRow(row_index)
            for column_index, column_data in enumerate(self.row_column):
                if column_data.type == TableTypeEnum.MENU:
                    self.set_menu(row_index, row_data)
                elif column_data.type == TableTypeEnum.TOGGLE:
                    self.set_toggle(row_index, column_data, row_data, column_index)
                elif column_data.type == TableTypeEnum.LABEL:
                    self.set_label(row_index, column_data, row_data, column_index)
                else:
                    self.set_default(row_index, column_data, row_data, column_index)

    def set_default(self, row_index: int, column_data: TableColumnModel, row_data: dict, column_index: int):
        cell_item = row_data[column_data.key]
        if isinstance(cell_item, dict):
            cell_item = cell_item.get(self.kwargs.get('dict_key', 'name'), json.dumps(cell_item, ensure_ascii=False))
        elif isinstance(cell_item, list):
            cell_item = json.dumps(cell_item, ensure_ascii=False)
        if column_data.option is not None:
            cell_item = self.get_option_value(column_data.option, cell_item)
        cell_item = QTableWidgetItem(str(cell_item) if cell_item is not None else '')
        self.setItem(row_index, column_index, cell_item)

    def set_toggle(self, row_index, column_data, row_data, column_index):
        cell_item = row_data[column_data.key]
        mango_toggle = MangoToggle()
        mango_toggle.click.connect(lambda data: self.toggle_click_but(data, row_data))
        mango_toggle.set_value(bool(cell_item))
        container = QWidget()

        layout = QHBoxLayout()
        layout.addWidget(mango_toggle, alignment=Qt.AlignCenter)  # type: ignore
        layout.setContentsMargins(0, 0, 0, 0)  # 去掉边距

        # 将布局设置到容器中
        container.setLayout(layout)

        # 将容器设置为单元格的控件
        self.setCellWidget(row_index, column_index, container)

    def toggle_click_but(self, data, row_data):
        data['row_data'] = row_data
        self.toggle_click.emit(data)

    def set_label(self, row_index, column_data, row_data, column_index):
        cell_item = row_data[column_data.key]
        if isinstance(cell_item, dict):
            cell_item = cell_item.get(self.kwargs.get('dict_key', 'name'), json.dumps(cell_item, ensure_ascii=False))
        elif isinstance(cell_item, list):
            cell_item = json.dumps(cell_item, ensure_ascii=False)
        if column_data.option is not None:
            cell_item = self.get_option_value(column_data.option, cell_item)
        label = MangoLabelWidget(str(cell_item) if cell_item is not None else '')
        self.setCellWidget(row_index, column_index, label)

    def set_menu(self, row, item):
        action_widget = QWidget()
        action_layout = QHBoxLayout(action_widget)
        for ope in self.row_ope:
            but = QPushButton(ope.name)
            but.setStyleSheet(
                'QPushButton { background-color: transparent; border: none; padding: 0; color: blue; font-size: 10px; }')
            but.setCursor(QCursor(Qt.PointingHandCursor))  # type: ignore
            action_layout.addWidget(but)
            if not ope.son:
                but.clicked.connect(partial(self.but_clicked, {'action': ope.action, 'row': item}))
            else:
                menu = QMenu()
                for ope1 in ope.son:
                    action = QAction(ope1.name, self)
                    action.triggered.connect(partial(self.but_clicked, {'action': ope1.action, 'row': item}))
                    menu.addAction(action)
                but.clicked.connect(lambda _, m=menu: m.exec_(QCursor.pos()))

        self.setCellWidget(row, len(self.row_column) - 1, action_widget)

    def get_option_value(self, option: list[dict], item1) -> str:
        for i in option:
            if i.get('children'):
                for e in i.get('children'):
                    if e.get('children'):
                        for q in e.get('children'):
                            if q.get('value') == item1:
                                return q.get('label')
                    else:
                        if e.get('value') == item1:
                            return e.get('label')
            if str(i.get('value')) == str(item1):
                return i.get('label')

    def but_clicked(self, data):
        self.click.emit(data)

    def mousePressEvent(self, event):
        local_pos = event.position().toPoint()
        item = self.itemAt(local_pos)
        if item:
            row = item.row()
            self.click.emit({'action': 'click_row', 'row': self.data[row]})
        super().mousePressEvent(event)

    def mouseMoveEvent(self, event):
        local_pos = event.position().toPoint()
        item = self.itemAt(local_pos)
        if item:
            text = item.text()
            rect = self.visualItemRect(item)
            if self.fontMetrics().horizontalAdvance(text) + 20 > rect.width():
                QToolTip.showText(QCursor.pos(), text)
            else:
                QToolTip.hideText()
        else:
            QToolTip.hideText()
        super().mouseMoveEvent(event)

    def get_selected_items(self):
        selected_items = []
        for row in range(self.rowCount()):
            if self.item(row, 1).isSelected():
                content_item = self.item(row, 0)
                selected_items.append(content_item.text())
        return selected_items

    def set_stylesheet(self):
        style = f'''
            /* QTableWidget */
            QTableWidget {{
                background-color: {THEME.bg_100};
                padding: 0px;
                border-radius: {THEME.border_radius};
                gridline-color: transparent;
                color: {THEME.text_100};
                border: 1px solid {THEME.bg_300};
                alternate-background-color: {THEME.bg_200};
            }}
            
            QTableWidget::item {{
                border: none;
                padding: 8px 10px;
                border-bottom: 1px solid {THEME.bg_300};
            }}
            
            QTableWidget::item:selected {{
                background-color: {THEME.primary_200};
                color: {THEME.text_100};
            }}
            
            QTableWidget::item:focus {{
                background-color: {THEME.primary_300};
            }}

            /* Header Sections */
            QHeaderView {{
                background-color: {THEME.bg_100};
                border: none;
            }}
            
            QHeaderView::section {{
                background-color: {THEME.primary_100};
                color: white;
                border: none;
                border-right: 1px solid {THEME.primary_200};
                padding: 10px;
                font-weight: 500;
                font-size: {THEME.font.text_size + 1}px;
            }}
            
            QHeaderView::section:last {{
                border-right: none;
            }}
            
            QHeaderView::section:horizontal {{
                border-top-left-radius: {THEME.border_radius};
                border-top-right-radius: {THEME.border_radius};
            }}
            
            QHeaderView::section:vertical {{
                border-bottom: 1px solid {THEME.bg_300};
            }}

            /* Table Corner Button */
            QTableWidget QTableCornerButton::section {{
                border: none;
                background-color: {THEME.primary_100};
                border-top-left-radius: {THEME.border_radius};
            }}

            /* ScrollBars */
            QScrollBar:horizontal {{
                border: none;
                background: {THEME.bg_200};
                height: 10px;
                margin: 0px 21px 0 21px;
                border-radius: 5px;
            }}
            
            QScrollBar::handle:horizontal {{
                background: {THEME.bg_300};
                min-width: 25px;
                border-radius: 5px;
            }}
            
            QScrollBar::add-line:horizontal {{
                border: none;
                background: {THEME.bg_300};
                width: 20px;
                border-top-right-radius: 5px;
                border-bottom-right-radius: 5px;
                subcontrol-position: right;
                subcontrol-origin: margin;
            }}
            
            QScrollBar::sub-line:horizontal {{
                border: none;
                background: {THEME.accent_100};
                width: 20px;
                border-top-left-radius: 5px;
                border-bottom-left-radius: 5px;
                subcontrol-position: left;
                subcontrol-origin: margin;
            }}
            
            QScrollBar::up-arrow:horizontal, QScrollBar::down-arrow:horizontal {{
                background: none;
            }}
            
            QScrollBar::add-page:horizontal, QScrollBar::sub-page:horizontal {{
                background: none;
            }}

            QScrollBar:vertical {{
                border: none;
                background: {THEME.bg_200};
                width: 10px;
                margin: 21px 0 21px 0;
                border-radius: 5px;
            }}
            
            QScrollBar::handle:vertical {{
                background: {THEME.bg_300};
                min-height: 25px;
                border-radius: 5px;
            }}
            
            QScrollBar::add-line:vertical {{
                border: none;
                background: {THEME.bg_300};
                height: 20px;
                border-bottom-left-radius: 5px;
                border-bottom-right-radius: 5px;
                subcontrol-position: bottom;
                subcontrol-origin: margin;
            }}
            
            QScrollBar::sub-line:vertical {{
                border: none;
                background: {THEME.bg_300};
                height: 20px;
                border-top-left-radius: 5px;
                border-top-right-radius: 5px;
                subcontrol-position: top;
                subcontrol-origin: margin;
            }}
            
            QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {{
                background: none;
            }}
            
            QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {{
                background: none;
            }}
        '''
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.input import MangoPushButton
from mangoui.widgets.layout import MangoVBoxLayout, MangoHBoxLayout, MangoGridLayout


class LayoutPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("布局组件展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织布局组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        self.components_grid.setColumnStretch(3, 1)
        
        # 三栏布局示例
        layout_widget = QWidget()
        main_layout = MangoHBoxLayout(layout_widget)
        
        # 左侧布局
        left_widget = QWidget()
        left_layout = MangoVBoxLayout(left_widget)
        left_layout.addWidget(QLabel("左侧内容1"))
        left_layout.addWidget(MangoPushButton("左侧按钮"))
        left_layout.addWidget(QLabel("左侧内容2"))
        
        # 中间布局
        center_widget = QWidget()
        center_layout = MangoVBoxLayout(center_widget)
        center_layout.addWidget(QLabel("中间内容1"))
        center_layout.addWidget(MangoPushButton("中间按钮"))
        center_layout.addWidget(QLabel("中间内容2"))
        
        # 右侧布局
        right_widget = QWidget()
        right_layout = MangoVBoxLayout(right_widget)
        right_layout.addWidget(QLabel("右侧内容1"))
        right_layout.addWidget(MangoPushButton("右侧按钮"))
        right_layout.addWidget(QLabel("右侧内容2"))
        
        main_layout.addWidget(left_widget)
        main_layout.addWidget(center_widget)
        main_layout.addWidget(right_widget)
        
        self.components_grid.addWidget(QLabel("三栏布局示例:"), 0, 0)
        self.components_grid.addWidget(layout_widget, 0, 1, 1, 3)

        # 网格布局示例
        grid_widget = QWidget()
        grid_layout = QGridLayout(grid_widget)
        for i in range(3):
            for j in range(3):
                grid_layout.addWidget(MangoPushButton(f"按钮{i+1}-{j+1}"), i, j)
        
        self.components_grid.addWidget(QLabel("网格布局示例:"), 1, 0)
        self.components_grid.addWidget(grid_widget, 1, 1, 1, 3)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 工具箱组件
# @Time   : 2025-11-25 10:55
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoToolBox(QToolBox):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QToolBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QToolBox::tab {{
            background-color: {THEME.primary_100};
            border: 1px solid {THEME.primary_200};
            color: white;
            padding: 8px 12px;
        }}

        QToolBox::tab:selected {{
            background-color: {THEME.primary_200};
            border: 1px solid {THEME.primary_300};
        }}

        QToolBox::tab:hover {{
            background-color: {THEME.primary_200};
        }}

        QToolBox::tab:selected:hover {{
            background-color: {THEME.primary_300};
        }}

        QToolBox::tab:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
            border: 1px solid {THEME.bg_300};
        }}

        QToolBox QScrollArea {{
            background-color: {THEME.bg_100};
            border: none;
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 数值输入框组件
# @Time   : 2025-11-25 10:00
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoSpinBox(QSpinBox):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QSpinBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QSpinBox:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QSpinBox:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QSpinBox::up-button {{
            subcontrol-origin: border;
            subcontrol-position: top right;
            width: 16px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-top-right-radius: {THEME.border_radius};
            background: {THEME.bg_100};
        }}

        QSpinBox::up-button:hover {{
            background: {THEME.bg_200};
        }}

        QSpinBox::up-arrow {{
            image: url(:/icons/up.svg);
            width: 10px;
            height: 10px;
        }}

        QSpinBox::up-arrow:disabled {{
            image: url(:/icons/up_disabled.svg);
        }}

        QSpinBox::down-button {{
            subcontrol-origin: border;
            subcontrol-position: bottom right;
            width: 16px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-bottom-right-radius: {THEME.border_radius};
            background: {THEME.bg_100};
        }}

        QSpinBox::down-button:hover {{
            background: {THEME.bg_200};
        }}

        QSpinBox::down-arrow {{
            image: url(:/icons/down.svg);
            width: 10px;
            height: 10px;
        }}

        QSpinBox::down-arrow:disabled {{
            image: url(:/icons/down_disabled.svg);
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(36)


class MangoDoubleSpinBox(QDoubleSpinBox):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QDoubleSpinBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QDoubleSpinBox:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QDoubleSpinBox:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QDoubleSpinBox::up-button {{
            subcontrol-origin: border;
            subcontrol-position: top right;
            width: 16px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-top-right-radius: {THEME.border_radius};
            background: {THEME.bg_100};
        }}

        QDoubleSpinBox::up-button:hover {{
            background: {THEME.bg_200};
        }}

        QDoubleSpinBox::up-arrow {{
            image: url(:/icons/up.svg);
            width: 10px;
            height: 10px;
        }}

        QDoubleSpinBox::up-arrow:disabled {{
            image: url(:/icons/up_disabled.svg);
        }}

        QDoubleSpinBox::down-button {{
            subcontrol-origin: border;
            subcontrol-position: bottom right;
            width: 16px;
            border-left-width: 1px;
            border-left-color: {THEME.bg_300};
            border-left-style: solid;
            border-bottom-right-radius: {THEME.border_radius};
            background: {THEME.bg_100};
        }}

        QDoubleSpinBox::down-button:hover {{
            background: {THEME.bg_200};
        }}

        QDoubleSpinBox::down-arrow {{
            image: url(:/icons/down.svg);
            width: 10px;
            height: 10px;
        }}

        QDoubleSpinBox::down-arrow:disabled {{
            image: url(:/icons/down_disabled.svg);
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(36)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-03-07 20:18
# @Author : 毛鹏
from PySide6.QtWidgets import QApplication, QWidget, QHBoxLayout, QLabel, QFrame

from mangoui.settings.settings import THEME


class MangoDashedLine(QWidget):
    def __init__(self, text=None, parent=None):
        super().__init__(parent)
        layout = QHBoxLayout(self)
        layout.setContentsMargins(0, 0, 0, 0)
        left_line = QFrame()
        left_line.setFrameShape(QFrame.HLine)
        left_line.setFrameShadow(QFrame.Sunken)
        left_line.setStyleSheet(f"border: 1px dashed {THEME.text_200}; margin: 0; padding: 0;")

        right_line = QFrame()
        right_line.setFrameShape(QFrame.HLine)
        right_line.setFrameShadow(QFrame.Sunken)
        right_line.setStyleSheet(f"border: 1px dashed {THEME.text_200}; margin: 0; padding: 0;")
        if text:
            label = QLabel(text)

            layout.addWidget(left_line, 1)
            layout.addWidget(label)  # 文本居中
            layout.addWidget(right_line, 1)
        else:
            layout.addWidget(left_line)

        # 设置布局
        self.setLayout(layout)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtGui import *
from PySide6.QtWidgets import *

# 从具体的组件模块中导入所需的组件
from mangoui.widgets.input import (
    MangoLineEdit, MangoSpinBox, MangoComboBox, MangoPushButton
)
from mangoui.models.models import ComboBoxDataModel
from mangoui.widgets.layout import MangoVBoxLayout, MangoGridLayout, MangoFormLayout


class Layout2Page(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = MangoVBoxLayout(self)
        
        # 创建滚动区域以容纳所有组件
        self.scroll_area = QScrollArea()
        self.scroll_area.setWidgetResizable(True)
        self.scroll_widget = QWidget()
        self.scroll_layout = MangoVBoxLayout(self.scroll_widget)
        
        # 标题
        title = QLabel("高级布局展示")
        title.setStyleSheet("font-size: 18px; font-weight: bold; margin: 10px 0;")
        self.scroll_layout.addWidget(title)

        # 使用网格布局组织高级布局组件，提高空间利用率
        self.components_grid = MangoGridLayout()
        self.components_grid.setColumnStretch(1, 1)
        
        # 表单布局示例
        form_widget = QWidget()
        form_layout = MangoFormLayout(form_widget)
        form_layout.addRow(QLabel("姓名:"), MangoLineEdit("请输入姓名"))
        form_layout.addRow(QLabel("邮箱:"), MangoLineEdit("请输入邮箱"))
        form_layout.addRow(QLabel("年龄:"), MangoSpinBox())
        # 创建具有 name 和 id 属性的对象
        gender_data = [
            type('obj', (object,), {'id': 1, 'name': '男'})(),
            type('obj', (object,), {'id': 2, 'name': '女'})()
        ]
        form_layout.addRow(QLabel("性别:"), MangoComboBox("请选择性别", gender_data))
        
        self.components_grid.addWidget(QLabel("表单布局示例:"), 0, 0)
        self.components_grid.addWidget(form_widget, 0, 1)

        # 分割布局示例
        splitter = QSplitter(Qt.Horizontal)  # type: ignore
        left_panel = QTextEdit("左侧面板")
        center_panel = QTextEdit("中间面板")
        right_panel = QTextEdit("右侧面板")
        splitter.addWidget(left_panel)
        splitter.addWidget(center_panel)
        splitter.addWidget(right_panel)
        
        self.components_grid.addWidget(QLabel("分割布局示例:"), 1, 0)
        self.components_grid.addWidget(splitter, 1, 1)
        
        self.scroll_layout.addLayout(self.components_grid)

        # 设置滚动区域
        self.scroll_area.setWidget(self.scroll_widget)
        self.layout.addWidget(self.scroll_area)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-18 11:11
# @Author : 毛鹏

from PySide6.QtCore import *
from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoTextEdit(QTextEdit):
    click = Signal(object)

    def __init__(self, placeholder, value: str | None = None, subordinate: str | None = None):
        super().__init__()
        self.value = value
        self.subordinate = subordinate

        if placeholder:
            self.setPlaceholderText(placeholder)

        if self.value:
            self.set_value(self.value)
        self.set_stylesheet()

    def set_value(self, text: str):
        self.setPlainText(text)

    def get_value(self):
        return self.toPlainText()

    def set_stylesheet(self):
        style = f"""
        QTextEdit {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 8px 12px;
            selection-color: white;
            selection-background-color: {THEME.primary_100};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
        }}

        QTextEdit:focus {{
            border: 1px solid {THEME.primary_100};
            background-color: {THEME.bg_100};
        }}
        
        QTextEdit:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        /* 添加滚动条样式以匹配全局样式 */
        QTextEdit QScrollBar:horizontal {{
            border: none;
            background: {THEME.bg_300};
            height: 8px;
            margin: 0px 21px;
            border-radius: 0px;
        }}
        
        QTextEdit QScrollBar::handle:horizontal {{
            background: {THEME.bg_300};
            min-width: 25px;
            border-radius: 4px;
        }}
        
        QTextEdit QScrollBar::add-line:horizontal {{
            border: none;
            background: {THEME.bg_300};
            width: 20px;
            border-top-right-radius: 4px;
            border-bottom-right-radius: 4px;
            subcontrol-position: right;
            subcontrol-origin: margin;
        }}
        
        QTextEdit QScrollBar::sub-line:horizontal {{
            border: none;
            background: {THEME.bg_300};
            width: 20px;
            border-top-left-radius: 4px;
            border-bottom-left-radius: 4px;
            subcontrol-position: left;
            subcontrol-origin: margin;
        }}
        
        QTextEdit QScrollBar::up-arrow:horizontal, QTextEdit QScrollBar::down-arrow:horizontal {{
            background: none;
        }}
        
        QTextEdit QScrollBar::add-page:horizontal, QTextEdit QScrollBar::sub-page:horizontal {{
            background: none;
        }}
        
        QTextEdit QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 21px 0;
            border-radius: 0px;
        }}
        
        QTextEdit QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        
        QTextEdit QScrollBar::add-line:vertical {{
            border: none;
            background: {THEME.bg_300};
            height: 20px;
            border-bottom-left-radius: 4px;
            border-bottom-right-radius: 4px;
            subcontrol-position: bottom;
            subcontrol-origin: margin;
        }}
        
        QTextEdit QScrollBar::sub-line:vertical {{
            border: none;
            background: {THEME.bg_300};
            height: 20px;
            border-top-left-radius: 4px;
            border-top-right-radius: 4px;
            subcontrol-position: top;
            subcontrol-origin: margin;
        }}
        
        QTextEdit QScrollBar::up-arrow:vertical, QTextEdit QScrollBar::down-arrow:vertical {{
            background: none;
        }}
        
        QTextEdit QScrollBar::add-page:vertical, QTextEdit QScrollBar::sub-page:vertical {{
            background: none;
        }}
        """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-23 17:42
# @Author : 毛鹏
import numpy
import pyqtgraph
from PySide6.QtWidgets import QVBoxLayout, QWidget

from mangoui.settings.settings import THEME


class MangoLinePlot(QWidget):
    def __init__(self, title, left, bottom):
        super().__init__()
        # 创建绘图窗口
        self.plot_widget = pyqtgraph.PlotWidget()
        # 设置卡片样式
        self.setStyleSheet(f"""
            background: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            padding: 16px;
        """)

        # 设置图表样式
        self.plot_widget.setBackground('transparent')
        self.plot_widget.setTitle(title, color=THEME.text_100, size=f'{THEME.font.title_size}pt')
        self.plot_widget.setLabel('left', left, color=THEME.text_200, size=f'{THEME.font.text_size}pt')
        self.plot_widget.setLabel('bottom', bottom, color=THEME.text_200, size=f'{THEME.font.text_size}pt')

        # 优化图例
        legend = self.plot_widget.addLegend()
        legend.setBrush('#FFFFFF')
        legend.setPen('#CCCCCC')
        legend.setLabelTextColor('#333333')
        legend.setOffset((10, 10))  # 调整图例位置

        # 启用鼠标交互
        self.plot_widget.setMouseEnabled(x=True, y=True)
        self.plot_widget.setMenuEnabled(False)

        # 布局
        layout = QVBoxLayout()
        layout.setContentsMargins(0, 0, 0, 0)
        layout.addWidget(self.plot_widget)
        self.setLayout(layout)

    def draw(self, data: list[dict]):
        self.plot_widget.clear()

        days = numpy.arange(len(data[0]['value'])) + 1
        # 使用更美观的颜色方案
        colors = ['#1f77b4', '#ff7f0e', '#2ca02c', '#d62728',
                  '#9467bd', '#8c564b', '#e377c2', '#7f7f7f',
                  '#bcbd22', '#17becf']

        for index, item in enumerate(data):
            color = colors[index % len(colors)]
            self.plot_widget.plot(
                days,
                item['value'],
                pen=pyqtgraph.mkPen(color, width=2.5),
                name=item['name'],
                width=2.5,
                symbol='o',
                symbolSize=8,
                symbolBrush=color,
                symbolPen='k',
                shadowPen=pyqtgraph.mkPen('#000000', width=1.5)
            )



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from PySide6.QtWidgets import *

from mangoui.settings.settings import THEME


class MangoSlider(QSlider):
    def __init__(self):
        super().__init__()

        self.set_style_sheet()

    def set_style_sheet(self):
        self.setStyleSheet(f"""
        /* HORIZONTAL */
        QSlider {{ 
            margin: 0px; 
        }}
        
        QSlider::groove:horizontal {{
            border-radius: 2px;
            height: 4px;
            margin: 0px;
            background-color: {THEME.bg_300};
        }}
        
        QSlider::groove:horizontal:hover {{ 
            background-color: {THEME.primary_200}; 
        }}
        
        QSlider::handle:horizontal {{
            border: none;
            height: 16px;
            width: 16px;
            margin: -6px 0;
            border-radius: 8px;
            background-color: {THEME.primary_100};
        }}
        
        QSlider::handle:horizontal:hover {{ 
            background-color: {THEME.primary_200}; 
        }}
        
        QSlider::handle:horizontal:pressed {{ 
            background-color: {THEME.primary_300}; 
        }}

        /* VERTICAL */
        QSlider::groove:vertical {{
            border-radius: 2px;
            width: 4px;
            margin: 0px;
            background-color: {THEME.bg_300};
        }}
        
        QSlider::groove:vertical:hover {{ 
            background-color: {THEME.primary_200}; 
        }}
        
        QSlider::handle:vertical {{
            border: none;
            height: 16px;
            width: 16px;
            margin: 0 -6px;
            border-radius: 8px;
            background-color: {THEME.primary_100};
        }}
        
        QSlider::handle:vertical:hover {{ 
            background-color: {THEME.primary_200}; 
        }}
        
        QSlider::handle:vertical:pressed {{ 
            background-color: {THEME.primary_300}; 
        }}
        """)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 输入
# @Time   : 2024-09-12 10:51
# @Author : 毛鹏
from .mang_time_edit import MangoTimeEdit
from .mango_cascader import MangoCascade
from .mango_checkbox import MangoCheckBox
from .mango_combo_box import MangoComboBox, MangoComboBoxMany
from .mango_icon_button import MangoIconButton
from .mango_line_edit import MangoLineEdit
from .mango_push_button import MangoPushButton
from .mango_slider import MangoSlider
from .mango_text_edit import MangoTextEdit
from .mango_toggle import MangoToggle
from .mango_spin_box import MangoSpinBox, MangoDoubleSpinBox
from .mango_date_edit import MangoDateEdit, MangoDateTimeEdit
from .mango_radio_button import MangoRadioButton
from .mango_plain_text_edit import MangoPlainTextEdit
from .mango_dial import MangoDial
from .mango_font_combo_box import MangoFontComboBox

__all__ = [
    'MangoTimeEdit',
    'MangoCascade',
    'MangoCheckBox',
    'MangoComboBox',
    'MangoComboBoxMany',
    'MangoIconButton',
    'MangoLineEdit',
    'MangoPushButton',
    'MangoSlider',
    'MangoTextEdit',
    'MangoToggle',
    'MangoSpinBox',
    'MangoDoubleSpinBox',
    'MangoDateEdit',
    'MangoDateTimeEdit',
    'MangoRadioButton',
    'MangoPlainTextEdit',
    'MangoDial',
    'MangoFontComboBox'
]


from setuptools import setup, find_packages

__version__ = '4.0.1'

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='mangoui',
    version=__version__,
    description='UI组件库',
    long_description=long_description,
    long_description_content_type="text/markdown",  # 添加这一行
    author='毛鹏',
    author_email='729164035@qq.com',
    url='https://gitee.com/mao-peng/MangoUi',
    packages=find_packages(),
    install_requires=[
        'pydantic>=2.9.2',
        'pyside6>=6.8.1',
        'matplotlib>=3.9.2',
        'numpy>=2.2.0',
        'pyqtgraph>=0.13.7'
    ],
    classifiers=[
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
)

r"""
pyside6-rcc D:\GitCode\MangoUi\mango_ui\resources\resources.qrc -o D:\GitCode\MangoUi\mango_ui\resources\app_rc.py

python -m pip install --upgrade setuptools wheel
python -m pip install --upgrade twine

python setup.py check
python setup.py sdist bdist_wheel
twine upload --repository-url https://upload.pypi.org/legacy/ dist/*

"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-08 16:14
# @Author : 毛鹏

from .models import *

__all__ = [
    'Font',
    'GroupColors',
    'State',
    'Theme',
    'LeftMenuSize',
    'ColumnSize',
    'AppConfig',
    'ThemeConfig',
    'LeftMenuModel',
    'TitleBarMenusModel',
    'MenusModel',
    'SearchDataModel',
    'RightDataModel',
    'FormDataModel',
    'TableColumnModel',
    'TableMenuItemModel',
    'FieldListModel',
    'CascaderModel',
    'TreeModel',
    'DialogCallbackModel',
    'ComboBoxDataModel'
]


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-14 17:30
# @Author : 毛鹏
from PySide6.QtCore import Signal
from PySide6.QtWidgets import QTabWidget, QWidget, QVBoxLayout

from mangoui.settings.settings import THEME


class MangoTabs(QTabWidget):
    clicked = Signal(str)

    def __init__(self):
        super().__init__()
        self.previous_index = 0
        self.setContentsMargins(0, 0, 0, 0)
        self.setStyleSheet(f"""
            QTabWidget {{
                background-color: {THEME.bg_100};
                border-radius: {THEME.border_radius};
            }}
            
            QTabBar {{
                background: transparent;
                border-bottom: 2px solid {THEME.bg_200};
                spacing: 4px;
                qproperty-drawBase: 0; /* 隐藏默认底线 */
            }}
            
            QTabBar::tab {{
                background: transparent;
                border: none;
                padding: 10px 20px;
                margin: 0 2px;
                color: {THEME.text_200};
                font-family: {THEME.font.family};
                font-size: {THEME.font.text_size}px;
                border-top-left-radius: {THEME.border_radius};
                border-top-right-radius: {THEME.border_radius};
                transition: all 0.3s ease;
            }}
            
            QTabBar::tab:selected {{
                color: {THEME.text_100};
                background-color: {THEME.bg_100};
                border-bottom: 2px solid {THEME.primary_100};
                font-weight: 600;
            }}
            
            QTabBar::tab:hover {{
                color: {THEME.text_100};
                background-color: {THEME.bg_200};
            }}
            
            QTabBar::tab:selected:hover {{
                background-color: {THEME.bg_100};
            }}
            
            QTabWidget::pane {{
                border: 1px solid {THEME.bg_300};
                border-top: none;
                padding: 16px;
                border-radius: 0 0 {THEME.border_radius} {THEME.border_radius};
                background-color: {THEME.bg_100};
            }}
            
            QTabBar::close-button {{
                image: url(:/icons/icon_close.svg);
                subcontrol-position: right;
                padding: 4px;
                border-radius: 4px;
            }}
            
            QTabBar::close-button:hover {{
                background: {THEME.primary_200};
            }}
        """)

    def add_tab(self, tab_name, widget):
        new_tab = QWidget()
        new_tab.setContentsMargins(0, 0, 0, 0)
        layout = QVBoxLayout()
        layout.setContentsMargins(0, 5, 0, 0)
        layout.addWidget(widget)
        new_tab.setLayout(layout)
        self.addTab(new_tab, tab_name)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 表格视图组件
# @Time   : 2025-11-25 10:30
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoTableView(QTableView):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QTableView {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
            gridline-color: {THEME.bg_300};
            selection-background-color: {THEME.primary_100};
            selection-color: white;
        }}

        QTableView::item {{
            padding: 8px 12px;
        }}

        QTableView::item:selected {{
            background-color: {THEME.primary_100};
            color: white;
        }}

        QTableView::item:hover {{
            background-color: {THEME.bg_200};
        }}

        QTableView::item:selected:hover {{
            background-color: {THEME.primary_200};
        }}

        QHeaderView::section {{
            background-color: {THEME.primary_100};
            color: white;
            padding: 8px 12px;
            border: 1px solid {THEME.primary_200};
            font-weight: bold;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QHeaderView::section:hover {{
            background-color: {THEME.primary_200};
        }}

        QTableView QTableCornerButton::section {{
            background-color: {THEME.primary_100};
            border: 1px solid {THEME.primary_200};
        }}

        QTableView:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QTableView QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTableView QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        
        QTableView QScrollBar:horizontal {{
            border: none;
            background: {THEME.bg_300};
            height: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTableView QScrollBar::handle:horizontal {{
            background: {THEME.bg_300};
            min-width: 25px;
            border-radius: 4px;
        }}
        """
        self.setStyleSheet(style)


class MangoTableWidget(QTableWidget):
    def __init__(self, parent=None, **kwargs):
        super().__init__(parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QTableWidget {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
            outline: none;
            gridline-color: {THEME.bg_300};
            selection-background-color: {THEME.primary_100};
            selection-color: white;
        }}

        QTableWidget::item {{
            padding: 8px 12px;
        }}

        QTableWidget::item:selected {{
            background-color: {THEME.primary_100};
            color: white;
        }}

        QTableWidget::item:hover {{
            background-color: {THEME.bg_200};
        }}

        QTableWidget::item:selected:hover {{
            background-color: {THEME.primary_200};
        }}

        QHeaderView::section {{
            background-color: {THEME.primary_100};
            color: white;
            padding: 8px 12px;
            border: 1px solid {THEME.primary_200};
            font-weight: bold;
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QHeaderView::section:hover {{
            background-color: {THEME.primary_200};
        }}

        QTableWidget QTableCornerButton::section {{
            background-color: {THEME.primary_100};
            border: 1px solid {THEME.primary_200};
        }}

        QTableWidget:disabled {{
            background-color: {THEME.bg_200};
            color: {THEME.text_200};
        }}
        
        QTableWidget QScrollBar:vertical {{
            border: none;
            background: {THEME.bg_300};
            width: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTableWidget QScrollBar::handle:vertical {{
            background: {THEME.bg_300};
            min-height: 25px;
            border-radius: 4px;
        }}
        
        QTableWidget QScrollBar:horizontal {{
            border: none;
            background: {THEME.bg_300};
            height: 8px;
            margin: 0px 0px 0px 0px;
            border-radius: 0px;
        }}
        
        QTableWidget QScrollBar::handle:horizontal {{
            background: {THEME.bg_300};
            min-width: 25px;
            border-radius: 4px;
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 分组框组件
# @Time   : 2025-11-25 10:45
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoGroupBox(QGroupBox):
    def __init__(self, title="", parent=None, **kwargs):
        super().__init__(title, parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QGroupBox {{
            background-color: {THEME.bg_100};
            border-radius: {THEME.border_radius};
            border: 1px solid {THEME.bg_300};
            margin-top: 1ex;
            font-family: {THEME.font.family};
            font-size: {THEME.font.title_size}px;
            font-weight: bold;
            color: {THEME.text_100};
        }}

        QGroupBox::title {{
            subcontrol-origin: margin;
            subcontrol-position: top left;
            padding: 0 8px;
            background-color: {THEME.bg_100};
        }}

        QGroupBox:disabled {{
            color: {THEME.text_200};
            border: 1px solid {THEME.bg_200};
        }}

        QGroupBox::title:disabled {{
            color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-24 17:16
# @Author : 毛鹏

from PySide6.QtWidgets import *
from PySide6.QtCore import *
from PySide6.QtGui import *

class MangoCheckBox(QCheckBox):
    def __init__(self, text=None, parent=None):
        super().__init__(parent)
        self.setText(text)
        self.get_style()

    def get_style(self):
        from mangoui.settings.settings import THEME
        style = f"""
        QCheckBox {{
            spacing: 8px;
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}
        
        QCheckBox::indicator {{
            width: 16px;
            height: 16px;
            border-radius: 4px;
            border: 1px solid {THEME.bg_300};
            background-color: {THEME.bg_100};
        }}
        
        QCheckBox::indicator:hover {{
            border: 1px solid {THEME.primary_100};
        }}
        
        QCheckBox::indicator:checked {{
            background-color: {THEME.primary_100};
            border: 1px solid {THEME.primary_100};
            image: url(:/icons/check.svg);
        }}
        
        QCheckBox:disabled {{
            color: {THEME.text_200};
        }}
        
        QCheckBox::indicator:disabled {{
            background-color: {THEME.bg_200};
            border: 1px solid {THEME.bg_300};
        }}
        
        QCheckBox::indicator:checked:disabled {{
            background-color: {THEME.bg_300};
            border: 1px solid {THEME.bg_300};
            image: url(:/icons/check_disabled.svg);
        }}
        """
        self.setStyleSheet(style)

    def isChecked(self):
        return super().isChecked()

    def setChecked(self, checked):
        super().setChecked(checked)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 单选按钮组件
# @Time   : 2025-11-25 10:10
# @Author : Qwen

from PySide6.QtCore import *
from PySide6.QtWidgets import *
from mangoui.settings.settings import THEME


class MangoRadioButton(QRadioButton):
    def __init__(self, text="", parent=None, **kwargs):
        super().__init__(text, parent)
        self.kwargs = kwargs
        self.set_stylesheet()
        
    def set_stylesheet(self):
        style = f"""
        QRadioButton {{
            spacing: 8px;
            color: {THEME.text_100};
            font-family: {THEME.font.family};
            font-size: {THEME.font.text_size}px;
        }}

        QRadioButton::indicator {{
            width: 18px;
            height: 18px;
        }}

        QRadioButton::indicator:unchecked {{
            border: 2px solid {THEME.bg_300};
            border-radius: 9px;
            background-color: {THEME.bg_100};
        }}

        QRadioButton::indicator:unchecked:hover {{
            border: 2px solid {THEME.primary_200};
        }}

        QRadioButton::indicator:unchecked:pressed {{
            border: 2px solid {THEME.primary_300};
            background-color: {THEME.bg_200};
        }}

        QRadioButton::indicator:checked {{
            border: 2px solid {THEME.primary_100};
            border-radius: 9px;
            background-color: {THEME.bg_100};
        }}

        QRadioButton::indicator:checked:hover {{
            border: 2px solid {THEME.primary_200};
        }}

        QRadioButton::indicator:checked:pressed {{
            border: 2px solid {THEME.primary_300};
        }}

        QRadioButton::indicator:checked:after {{
            content: "";
            width: 10px;
            height: 10px;
            border-radius: 5px;
            background-color: {THEME.primary_100};
            position: absolute;
            top: 4px;
            left: 4px;
        }}

        QRadioButton:disabled {{
            color: {THEME.text_200};
        }}

        QRadioButton::indicator:disabled {{
            border: 2px solid {THEME.bg_200};
        }}

        QRadioButton::indicator:checked:disabled:after {{
            background-color: {THEME.text_200};
        }}
        """
        self.setStyleSheet(style)
        self.setMinimumHeight(30)


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 显示（通知）
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏
from .mango_circular_progress import MangoCircularProgress
from .mango_label import MangoLabel, MangoLabelWidget
from .mango_line import MangoDashedLine
from .mango_message import MangoMessage
from .mango_notification import MangoNotification
from .mango_pagination import MangoPagination
from .mango_table import MangoTable
from .mango_list_view import MangoListView
from .mango_list_widget import MangoListWidget
from .mango_tree_view import MangoTreeView
from .mango_tree_widget import MangoTreeWidget
from .mango_table_view import MangoTableView
from .mango_table_widget import MangoTableWidget
from .mango_lcd_number import MangoLCDNumber
from .mango_progress_bar import MangoProgressBar
from .mango_calendar_widget import MangoCalendarWidget
from .mango_status_bar import MangoStatusBar

__all__ = [
    'MangoCircularProgress',
    'MangoLabel',
    'MangoLabelWidget',
    'MangoDashedLine',
    'MangoMessage',
    'MangoNotification',
    'MangoPagination',
    'MangoTable',
    'MangoListView',
    'MangoListWidget',
    'MangoTreeView',
    'MangoTreeWidget',
    'MangoTableView',
    'MangoTableWidget',
    'MangoLCDNumber',
    'MangoProgressBar',
    'MangoCalendarWidget',
    'MangoStatusBar'
]